# --------------------------------------------------------------------------
# This is the python NGL wrapper project
# it needs to be built using the following commands
# qmake PyNGL.pro; make -f Makefile.pyngl
# If using QtCreator set the build setting in the Projects panel to add
# -f Makefile.pyngl
# and the clean to
# clean -f Makefile.pyngl
#---------------------------------------------------------------------------
# first set some global Qt settings
QT += opengl
QT += core
QT += gui
QT +=xml
CONFIG += console
CONFIG -= app_bundle
# this is the name of the makefile to produce
MAKEFILE=Makefile.pyngl
# set the base directory of our project so Qt knows where to find them
# we can use shell vars but need to use $$
BASE_DIR = $$(HOME)/NGL
# This is the output target we want to create
TARGET = $$BASE_DIR/lib/PyNGL.so
# this is where we want to put the intermediate build files ( ../objPy)
# this is different from the main NGL obj directory as we include different
# elements in this build for the python wrapper
OBJECTS_DIR = $$BASE_DIR/obj/objPy
QMAKE_LFLAGS-= -headerpad_max_install_names
QMAKE_LFLAGS_SHLIB -= -single_module
QMAKE_LFLAGS_VERSION=
QMAKE_LFLAGS_COMPAT_VERSION=
QMAKE_LFLAGS_SONAME=
# This define is an opt in for the python bindings, we need to set this to build
DEFINES+=NO_PYTHON_LIB
# define the NGL_DEBUG flag for the graphics lib
DEFINES += NGL_DEBUG

# this is where to look for includes
INCLUDEPATH += $$BASE_DIR/include/ngl
INCLUDEPATH += $$BASE_DIR/src/ngl
INCLUDEPATH +=/usr/local/boost
#set some flags for sse etc
QMAKE_CXXFLAGS+= -msse -msse2 -msse3

# and the include files
INC_DIR = $$BASE_DIR/include/ngl
# this flag adds the .h files to the build deps
DEPENDPATH= $$INC_DIR
# this tells the project where to look for the python wrapper files
PYTHON_DIR=$$BASE_DIR/python
# where to look for other libs
LIBS += -L/usr/local/lib

# set the SRC_DIR so we can find the project files
SRC_DIR = $$BASE_DIR/src

# here are the mac os x flags at the moment it's set for 64bit Snowleopard build
# if we are on a mac define DARWIN
macx:DEFINES += DARWIN
macx:QMAKE_CXXFLAGS+= -arch x86_64 -fPIC
macx:LIBS+= -framework OpenGL
macx:LIBS+= -framework Python
macx:LIBS+= -L/System/Library/Frameworks/Python.framework/ -famework Python
macx:INCLUDEPATH+=/System/Library/Frameworks/Python.framework/Headers
macx:LIBS+=  -Wl,-framework,Cocoa
macx:LIBS+= -L/Users/jmacey/teaching/boost_1_44_0/bin.v2/libs/python/build/darwin-4.2.1/release -lboost_python
macx:LIBS+= -L/System/Library/Frameworks/Python.framework/Versions/2.6/lib -lpython2.6
macx:QMAKE_LFLAGS+= -dynamiclib -install_name  "PyNGL.so"
macx:QMAKE_CXXFLAGS += -ftemplate-depth-128 -fno-inline -dynamic -no-cpp-precomp -gdwarf-2

# on linux we can use the native flag and it will pick up the correct version
# the unix flag works for both Mac and Linux if we want linux only
# we need to use the linux-g++ flag
linux-g++:QMAKE_CXXFLAGS+= -march=native -fPIC -shared
linux-g++:LIBS+= -lboost_python -l python2.6
linux-g++:INCLUDEPATH+=/usr/include/python2.6
linux-g++:QMAKE_LFLAGS+= -shared
linux-g++:DEFINES += LINUX
linux-g++:LIBS+=-lGLEW

linux-g++-64:QMAKE_CXXFLAGS+= -march=native -fPIC -shared
linux-g++-64:LIBS+= -lboost_python -l python2.6
linux-g++-64:INCLUDEPATH+=/usr/include/python2.6
linux-g++-64:QMAKE_LFLAGS+= -shared
linux-g++-64:DEFINES += LINUX
linux-g++-64:LIBS+=-lGLEW

# The windows configuration is very frustrating however I seem to have it working now
# You will need to install the following
# Qt and Boost++
# once you have done this set the PATH environment variable to look in
# c:\NGL\lib to find the DLL
win32:message(Please Ensure you have boost_1_44_0 installed and in the directory below)
win32:message(you will also need to set you path to point to C:\NGL\lib and the Qt install)
win32:message(directories C:\Qt\bin C:\Qt\qt\bin as this is where the debug libs are)
win32:LIBS += -lmingw32
win32:LIBS += -lstdc++
win32:DEFINES += WIN32
win32:DEFINES += USING_GLEW
win32:DEFINES +=GLEW_STATIC
win32:INCLUDEPATH += C:/boost_1_44_0
win32:LIBS += -L/lib/w32api
win32:DESTDIR = c:/
win32:message("You may need to change the python path I'm using Python27 here")
win32:INCLUDEPATH+=C:/Python27/include
# under windows for ease I hard code in the glew functions to save issues with linking
win32:SOURCES+=$$BASE_DIR/Support/glew/glew.c
win32:INCLUDEPATH+=$$BASE_DIR/Support/glew/
win32:DEFINES+=_WIN32
win32:CONFIG+=dll

# Here are the source files used for the project
SOURCES += \
    $$PYTHON_DIR/PythonWrapper.cpp \
		$$SRC_DIR/Vector.cpp \
    $$SRC_DIR/VBOPrimitives.cpp \
    $$SRC_DIR/Util.cpp \
    $$SRC_DIR/Texture.cpp \
    $$SRC_DIR/SpotLight.cpp \
    $$SRC_DIR/ShaderManager.cpp \
    $$SRC_DIR/Transformation.cpp \
    $$SRC_DIR/RibExport.cpp \
    $$SRC_DIR/Quaternion.cpp \
    $$SRC_DIR/PathCamera.cpp \
    $$SRC_DIR/Obj.cpp \
    $$SRC_DIR/Matrix.cpp \
    $$SRC_DIR/TransformStack.cpp \
    $$SRC_DIR/Material.cpp \
    $$SRC_DIR/Light.cpp \
    $$SRC_DIR/NGLInit.cpp \
    $$SRC_DIR/Colour.cpp \
    $$SRC_DIR/Clip.cpp \
    $$SRC_DIR/Camera.cpp \
    $$SRC_DIR/NCCABinMesh.cpp \
    $$SRC_DIR/BezierCurve.cpp \
    $$SRC_DIR/BBox.cpp \
    $$SRC_DIR/AbstractMesh.cpp \
    $$SRC_DIR/HoudiniGeo.cpp \
    $$SRC_DIR/Random.cpp \
    $$SRC_DIR/NCCAPointBake.cpp \
    $$SRC_DIR/Shader.cpp \
    $$SRC_DIR/ShaderProgram.cpp \
		$$SRC_DIR/Plane.cpp \
		$$SRC_DIR/AABB.cpp

# here are the .h headers
HEADERS += $$INC_DIR/Vector.h \
    $$INC_DIR/VBOPrimitives.h \
    $$INC_DIR/Singleton.h \
    $$INC_DIR/Util.h \
    $$INC_DIR/Types.h \
    $$INC_DIR/Texture.h \
    $$INC_DIR/SpotLight.h \
    $$INC_DIR/ShaderManager.h \
    $$INC_DIR/RibExport.h \
    $$INC_DIR/Transformation.h \
    $$INC_DIR/Quaternion.h \
    $$INC_DIR/PathCamera.h \
    $$INC_DIR/Obj.h \
    $$INC_DIR/NGLassert.h \
    $$INC_DIR/Matrix.h \
    $$INC_DIR/TransformStack.h \
    $$INC_DIR/Material.h \
    $$INC_DIR/Light.h \
    $$INC_DIR/NGLInit.h \
    $$INC_DIR/Colour.h \
    $$INC_DIR/Clip.h \
    $$INC_DIR/Camera.h \
    $$INC_DIR/BezierCurve.h \
    $$INC_DIR/NCCABinMesh.h \
    $$INC_DIR/BBox.h \
    $$INC_DIR/AbstractMesh.h \
    $$INC_DIR/HoudiniGeo.h \
    $$INC_DIR/Random.h \
    $$INC_DIR/NCCAPointBake.h \
    $$INC_DIR/Shader.h \
    $$INC_DIR/ShaderProgram.h \
		$$INC_DIR/Plane.h \
		$$INC_DIR/AABB.h


# in this project these files are included from Python wrapper .cpp these are included
# here so we can access and edit them hence being in the OtherFiles component
OTHER_FILES+= Doxyfile \
              $$PYTHON_DIR/Colour.inc.h \
              $$PYTHON_DIR/Colour.inc.cpp \
              $$PYTHON_DIR/Vector.inc.h \
              $$PYTHON_DIR/Vector.inc.cpp \
              $$PYTHON_DIR/Matrix.inc.cpp \
              $$PYTHON_DIR/Matrix.inc.h \
              $$PYTHON_DIR/Quaternion.inc.cpp \
              $$PYTHON_DIR/Quaternion.inc.h \
              $$PYTHON_DIR/BBox.inc.h \
              $$PYTHON_DIR/Camera.inc.h \
              $$PYTHON_DIR/VBOPrimitives.inc.h \
              $$PYTHON_DIR/Light.inc.h \
              $$PYTHON_DIR/Material.inc.cpp \
              $$PYTHON_DIR/Material.inc.h \
              $$PYTHON_DIR/AbstractMesh.inc.h \
              $$PYTHON_DIR/AbstractMesh.inc.cpp \
              $$PYTHON_DIR/Obj.inc.h \
              $$PYTHON_DIR/ShaderManager.inc.h \
              $$PYTHON_DIR/ShaderManager.inc.cpp \
              $$PYTHON_DIR/Transformation.inc.cpp \
              $$PYTHON_DIR/Transformation.inc.h \
              $$PYTHON_DIR/TransformStack.inc.cpp \
              $$PYTHON_DIR/TransformStack.inc.h \
              $$PYTHON_DIR/Texture.inc.h \
              $$PYTHON_DIR/BezierCurve.inc.cpp \
              $$PYTHON_DIR/BezierCurve.inc.h \
              $$PYTHON_DIR/PathCamera.inc.h \
              $$PYTHON_DIR/HoudiniGeo.inc.h \
              $$PYTHON_DIR/Clip.inc.cpp \
              $$PYTHON_DIR/Clip.inc.h \
              $$PYTHON_DIR/NCCABinMesh.inc.h \
              $$PYTHON_DIR/SpotLight.inc.h \
              $$PYTHON_DIR/Random.inc.cpp \
              $$PYTHON_DIR/Random.inc.h \
              $$PYTHON_DIR/NCCAPointBake.inc.h \
              $$PYTHON_DIR/NGLInit.inc.h \
              $$PYTHON_DIR/Shader.inc.h \
              $$PYTHON_DIR/ShaderProgram.inc.h \
							$$PYTHON_DIR/Plane.inc.h
